@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2022, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2023, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -26,9 +26,8 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
- * Distributed under the Terms of Use in 
- * http://www.unicode.org/copyright.html.
+ * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
+ * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
  * a copy of the Unicode data files and any associated documentation
@@ -37,14 +36,11 @@
  * without restriction, including without limitation the rights to use,
  * copy, modify, merge, publish, distribute, and/or sell copies of
  * the Data Files or Software, and to permit persons to whom the Data Files
- * or Software are furnished to do so, provided that
- * (a) this copyright and permission notice appear with all copies 
- * of the Data Files or Software,
- * (b) this copyright and permission notice appear in associated 
- * documentation, and
- * (c) there is clear notice in each modified Data File or in the Software
- * as well as in the documentation associated with the Data File(s) or
- * Software that the data or software has been modified.
+ * or Software are furnished to do so, provided that either
+ * (a) this copyright and permission notice appear with all copies
+ * of the Data Files or Software, or
+ * (b) this copyright and permission notice appear in associated
+ * Documentation.
  *
  * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
  * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
@@ -93,7 +89,7 @@ public class LocaleNames_pa extends OpenListResourceBundle {
         final String metaValue_te = "\u0a24\u0a47\u0a32\u0a17\u0a42";
         final String metaValue_th = "\u0a25\u0a3e\u0a08";
         final Object[][] data = new Object[][] {
-            { "ksh", "\u0a15\u0a32\u0a4b\u0a17\u0a28\u0a40\u0a05\u0a28" },
+            { "ksh", "\u0a15\u0a32\u0a4b\u0a28\u0a40\u0a05\u0a28" },
             { "mwl", "\u0a2e\u0a3f\u0a30\u0a3e\u0a02\u0a21\u0a40" },
             { "Zsym", "\u0a1a\u0a3f\u0a70\u0a28\u0a4d\u0a39" },
             { "Zsye", "\u0a07\u0a2e\u0a4b\u0a1c\u0a40" },
@@ -220,7 +216,6 @@ public class LocaleNames_pa extends OpenListResourceBundle {
             { "FO", "\u0a2b\u0a48\u0a30\u0a4b \u0a1f\u0a3e\u0a2a\u0a42" },
             { "Taml", metaValue_ta },
             { "FR", "\u0a2b\u0a3c\u0a30\u0a3e\u0a02\u0a38" },
-            { "root", "\u0a30\u0a42\u0a1f" },
             { "type.ca.indian", "\u0a2d\u0a3e\u0a30\u0a24\u0a40 \u0a15\u0a4c\u0a2e\u0a40 \u0a15\u0a48\u0a32\u0a70\u0a21\u0a30" },
             { "grc", "\u0a2a\u0a41\u0a30\u0a3e\u0a24\u0a28 \u0a2f\u0a42\u0a28\u0a3e\u0a28\u0a40" },
             { "GA", "\u0a17\u0a2c\u0a4b\u0a28" },
@@ -242,6 +237,7 @@ public class LocaleNames_pa extends OpenListResourceBundle {
             { "GT", "\u0a17\u0a41\u0a06\u0a1f\u0a47\u0a2e\u0a3e\u0a32\u0a3e" },
             { "GU", "\u0a17\u0a41\u0a06\u0a2e" },
             { "GW", "\u0a17\u0a3f\u0a28\u0a40-\u0a2c\u0a3f\u0a38\u0a3e\u0a09" },
+            { "rhg", "\u0a30\u0a4b\u0a39\u0a3f\u0a70\u0a17\u0a3f\u0a06" },
             { "tlh", "\u0a15\u0a32\u0a3f\u0a70\u0a17\u0a28" },
             { "GY", "\u0a17\u0a41\u0a2f\u0a3e\u0a28\u0a3e" },
             { "ckb", "\u0a15\u0a47\u0a02\u0a26\u0a30\u0a40 \u0a15\u0a41\u0a30\u0a26\u0a3f\u0a38\u0a3c" },
@@ -300,7 +296,7 @@ public class LocaleNames_pa extends OpenListResourceBundle {
             { "tpi", "\u0a1f\u0a4b\u0a15 \u0a2a\u0a3f\u0a38\u0a3f\u0a28" },
             { "KY", "\u0a15\u0a47\u0a2e\u0a48\u0a28 \u0a1f\u0a3e\u0a2a\u0a42" },
             { "KZ", "\u0a15\u0a1c\u0a3c\u0a3e\u0a16\u0a38\u0a24\u0a3e\u0a28" },
-            { "Cyrl", "\u0a38\u0a3f\u0a30\u0a40\u0a32\u0a3f\u0a15" },
+            { "Cyrl", "\u0a38\u0a3f\u0a30\u0a3f\u0a32\u0a3f\u0a15" },
             { "LA", "\u0a32\u0a3e\u0a13\u0a38" },
             { "LB", "\u0a32\u0a48\u0a2c\u0a28\u0a3e\u0a28" },
             { "LC", "\u0a38\u0a47\u0a02\u0a1f \u0a32\u0a42\u0a38\u0a40\u0a06" },
@@ -683,6 +679,7 @@ public class LocaleNames_pa extends OpenListResourceBundle {
             { "iu", "\u0a07\u0a70\u0a15\u0a1f\u0a40\u0a1f\u0a42\u0a24" },
             { "ja", metaValue_ja },
             { "Mlym", metaValue_ml },
+            { "doi", "\u0a21\u0a4b\u0a17\u0a30\u0a40" },
             { "sma", "\u0a26\u0a71\u0a16\u0a23\u0a40 \u0a38\u0a3e\u0a2e\u0a40" },
             { "jv", "\u0a1c\u0a3e\u0a35\u0a3e\u0a28\u0a40\u0a1c\u0a3c" },
             { "mad", "\u0a2e\u0a3e\u0a21\u0a42\u0a30\u0a40\u0a38" },
@@ -891,7 +888,7 @@ public class LocaleNames_pa extends OpenListResourceBundle {
             { "es_MX", "\u0a38\u0a2a\u0a47\u0a28\u0a40 (\u0a2e\u0a48\u0a15\u0a38\u0a40\u0a15\u0a40)" },
             { "vai", "\u0a35\u0a3e\u0a08" },
             { "kln", "\u0a15\u0a32\u0a47\u0a1c\u0a3f\u0a28" },
-            { "zh", "\u0a1a\u0a40\u0a28\u0a40 (\u0a2e\u0a48\u0a02\u0a21\u0a30\u0a3f\u0a28)" },
+            { "zh", "\u0a1a\u0a40\u0a28\u0a40" },
             { "Bopo", "\u0a2c\u0a4b\u0a2a\u0a4b\u0a2e\u0a4b\u0a2b\u0a4b" },
             { "key.lb", "\u0a30\u0a47\u0a16\u0a3e \u0a35\u0a3f\u0a71\u0a25 \u0a38\u0a3c\u0a48\u0a32\u0a40" },
             { "zu", "\u0a1c\u0a3c\u0a41\u0a32\u0a42" },
@@ -900,10 +897,8 @@ public class LocaleNames_pa extends OpenListResourceBundle {
             { "type.nu.jpanfin", "\u0a1c\u0a2a\u0a3e\u0a28\u0a40 \u0a35\u0a3f\u0a71\u0a24\u0a40 \u0a38\u0a70\u0a16\u0a3f\u0a06\u0a35\u0a3e\u0a02" },
             { "gez", "\u0a1c\u0a40\u0a1c\u0a3c" },
             { "ebu", "\u0a07\u0a70\u0a2c\u0a42" },
-            { "zh_Hans", "\u0a1a\u0a40\u0a28\u0a40 (\u0a38\u0a30\u0a32)" },
             { "koi", "\u0a15\u0a4b\u0a2e\u0a40-\u0a2a\u0a47\u0a30\u0a2e\u0a3f\u0a06\u0a15" },
             { "kok", "\u0a15\u0a4b\u0a02\u0a15\u0a23\u0a40" },
-            { "zh_Hant", "\u0a1a\u0a40\u0a28\u0a40 (\u0a30\u0a35\u0a3e\u0a07\u0a24\u0a40)" },
             { "kpe", "\u0a15\u0a2a\u0a47\u0a32" },
             { "type.nu.khmr", "\u0a16\u0a2e\u0a47\u0a30 \u0a05\u0a70\u0a15" },
             { "ilo", "\u0a07\u0a32\u0a4b\u0a15\u0a4b" },
