@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2022, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2023, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -26,9 +26,8 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
- * Distributed under the Terms of Use in 
- * http://www.unicode.org/copyright.html.
+ * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
+ * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
  * a copy of the Unicode data files and any associated documentation
@@ -37,14 +36,11 @@
  * without restriction, including without limitation the rights to use,
  * copy, modify, merge, publish, distribute, and/or sell copies of
  * the Data Files or Software, and to permit persons to whom the Data Files
- * or Software are furnished to do so, provided that
- * (a) this copyright and permission notice appear with all copies 
- * of the Data Files or Software,
- * (b) this copyright and permission notice appear in associated 
- * documentation, and
- * (c) there is clear notice in each modified Data File or in the Software
- * as well as in the documentation associated with the Data File(s) or
- * Software that the data or software has been modified.
+ * or Software are furnished to do so, provided that either
+ * (a) this copyright and permission notice appear with all copies
+ * of the Data Files or Software, or
+ * (b) this copyright and permission notice appear in associated
+ * Documentation.
  *
  * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
  * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
@@ -286,6 +282,14 @@ public class TimeZoneNames_es extends TimeZoneNamesBundle {
                "hora de Tonga",
                "",
             };
+        final String[] Yukon = new String[] {
+               "hora de Yuk\u00f3n",
+               "",
+               "",
+               "",
+               "",
+               "",
+            };
         final String[] Alaska = new String[] {
                "hora est\u00e1ndar de Alaska",
                "",
@@ -766,14 +770,6 @@ public class TimeZoneNames_es extends TimeZoneNamesBundle {
                "hora de Lord Howe",
                "",
             };
-        final String[] Macquarie = new String[] {
-               "hora de la isla Macquarie",
-               "",
-               "",
-               "",
-               "",
-               "",
-            };
         final String[] Marquesas = new String[] {
                "hora de Marquesas",
                "",
@@ -1300,7 +1296,7 @@ public class TimeZoneNames_es extends TimeZoneNamesBundle {
             { "Asia/Macau", China },
             { "Asia/Qatar", Arabian },
             { "Asia/Seoul", Korea },
-            { "Africa/Juba", Africa_Eastern },
+            { "Africa/Juba", Africa_Central },
             { "Africa/Lome", GMT },
             { "Asia/Almaty", Kazakhstan_Eastern },
             { "Asia/Anadyr", Anadyr },
@@ -1450,7 +1446,7 @@ public class TimeZoneNames_es extends TimeZoneNamesBundle {
             { "America/Cancun", America_Eastern },
             { "America/Cayman", America_Eastern },
             { "America/Cuiaba", Amazon },
-            { "America/Dawson", America_Pacific },
+            { "America/Dawson", Yukon },
             { "America/Guyana", Guyana },
             { "America/Havana", Cuba },
             { "America/Inuvik", America_Mountain },
@@ -1576,7 +1572,6 @@ public class TimeZoneNames_es extends TimeZoneNamesBundle {
             { "America/St_Kitts", Atlantic },
             { "America/St_Lucia", Atlantic },
             { "America/Winnipeg", America_Central },
-            { "Antarctica/Casey", Australia_Western },
             { "Antarctica/Davis", Davis },
             { "Antarctica/Syowa", Syowa },
             { "Antarctica/Troll", GMT },
@@ -1657,7 +1652,7 @@ public class TimeZoneNames_es extends TimeZoneNamesBundle {
             { "America/Paramaribo", Suriname },
             { "America/Rio_Branco", Acre },
             { "America/St_Vincent", Atlantic },
-            { "America/Whitehorse", America_Pacific },
+            { "America/Whitehorse", Yukon },
             { "Antarctica/McMurdo", New_Zealand },
             { "Antarctica/Rothera", Rothera },
             { "Asia/Yekaterinburg", Yekaterinburg },
@@ -1697,7 +1692,7 @@ public class TimeZoneNames_es extends TimeZoneNamesBundle {
             { "America/Rankin_Inlet", America_Central },
             { "America/Santa_Isabel", Mexico_Northwest },
             { "America/Scoresbysund", Greenland_Eastern },
-            { "Antarctica/Macquarie", Macquarie },
+            { "Antarctica/Macquarie", Australia_Eastern },
             { "Pacific/Port_Moresby", Papua_New_Guinea },
             { "America/Cambridge_Bay", America_Mountain },
             { "America/Coral_Harbour", America_Eastern },
@@ -1761,7 +1756,7 @@ public class TimeZoneNames_es extends TimeZoneNamesBundle {
             { "timezone.excity.Asia/Taipei", "Taip\u00e9i" },
             { "timezone.excity.Asia/Tehran", "Teher\u00e1n" },
             { "timezone.excity.Asia/Urumqi", "\u00dcr\u00fcmqi" },
-            { "timezone.excity.Etc/Unknown", "ciudad desconocida" },
+            { "timezone.excity.Etc/Unknown", "Ciudad desconocida" },
             { "timezone.excity.Europe/Kiev", "Kiev" },
             { "timezone.excity.Europe/Oslo", "Oslo" },
             { "timezone.excity.Europe/Riga", "Riga" },
@@ -1919,7 +1914,7 @@ public class TimeZoneNames_es extends TimeZoneNamesBundle {
             { "timezone.excity.Africa/El_Aaiun", "El Aai\u00fan" },
             { "timezone.excity.Africa/Freetown", "Freetown" },
             { "timezone.excity.Africa/Gaborone", "Gaborone" },
-            { "timezone.excity.Africa/Khartoum", "Jart\u00fan" },
+            { "timezone.excity.Africa/Khartoum", "Jartum" },
             { "timezone.excity.Africa/Kinshasa", "Kinshasa" },
             { "timezone.excity.Africa/Monrovia", "Monrovia" },
             { "timezone.excity.Africa/Ndjamena", "Yamena" },
@@ -1961,7 +1956,7 @@ public class TimeZoneNames_es extends TimeZoneNamesBundle {
             { "timezone.excity.Europe/Budapest", "Budapest" },
             { "timezone.excity.Europe/Busingen", "Busingen" },
             { "timezone.excity.Europe/Chisinau", "Chisin\u00e1u" },
-            { "timezone.excity.Europe/Guernsey", "Guernsey" },
+            { "timezone.excity.Europe/Guernsey", "Guernesey" },
             { "timezone.excity.Europe/Helsinki", "Helsinki" },
             { "timezone.excity.Europe/Istanbul", "Estambul" },
             { "timezone.excity.Europe/Sarajevo", "Sarajevo" },
@@ -2060,7 +2055,7 @@ public class TimeZoneNames_es extends TimeZoneNamesBundle {
             { "timezone.excity.Pacific/Pago_Pago", "Pago Pago" },
             { "timezone.excity.Pacific/Rarotonga", "Rarotonga" },
             { "timezone.excity.Pacific/Tongatapu", "Tongatapu" },
-            { "timezone.excity.Africa/Addis_Ababa", "Addis Abeba" },
+            { "timezone.excity.Africa/Addis_Ababa", "Ad\u00eds Abeba" },
             { "timezone.excity.Africa/Brazzaville", "Brazzaville" },
             { "timezone.excity.Africa/Ouagadougou", "Uagadug\u00fa" },
             { "timezone.excity.America/Costa_Rica", "Costa Rica" },
@@ -2107,7 +2102,7 @@ public class TimeZoneNames_es extends TimeZoneNamesBundle {
             { "timezone.excity.Australia/Melbourne", "Melbourne" },
             { "timezone.excity.Indian/Antananarivo", "Antananarivo" },
             { "timezone.excity.Pacific/Guadalcanal", "Guadalcanal" },
-            { "timezone.excity.Africa/Dar_es_Salaam", "Dar es Salaam" },
+            { "timezone.excity.Africa/Dar_es_Salaam", "Dar es-Salam" },
             { "timezone.excity.America/Blanc-Sablon", "Blanc-Sablon" },
             { "timezone.excity.America/Buenos_Aires", "Buenos Aires" },
             { "timezone.excity.America/Campo_Grande", "Campo Grande" },
