@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2022, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2023, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -26,9 +26,8 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
- * Distributed under the Terms of Use in 
- * http://www.unicode.org/copyright.html.
+ * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
+ * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
  * a copy of the Unicode data files and any associated documentation
@@ -37,14 +36,11 @@
  * without restriction, including without limitation the rights to use,
  * copy, modify, merge, publish, distribute, and/or sell copies of
  * the Data Files or Software, and to permit persons to whom the Data Files
- * or Software are furnished to do so, provided that
- * (a) this copyright and permission notice appear with all copies 
- * of the Data Files or Software,
- * (b) this copyright and permission notice appear in associated 
- * documentation, and
- * (c) there is clear notice in each modified Data File or in the Software
- * as well as in the documentation associated with the Data File(s) or
- * Software that the data or software has been modified.
+ * or Software are furnished to do so, provided that either
+ * (a) this copyright and permission notice appear with all copies
+ * of the Data Files or Software, or
+ * (b) this copyright and permission notice appear in associated
+ * Documentation.
  *
  * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
  * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
@@ -278,6 +274,14 @@ public class TimeZoneNames_pcm extends TimeZoneNamesBundle {
                "T\u1ecd\u0301nga Taim",
                "",
             };
+        final String[] Yukon = new String[] {
+               "Yuk\u00f3n Taim",
+               "",
+               "",
+               "",
+               "",
+               "",
+            };
         final String[] Alaska = new String[] {
                "Al\u00e1sk\u00e1 F\u00edksd Taim",
                "",
@@ -505,7 +509,7 @@ public class TimeZoneNames_pcm extends TimeZoneNamesBundle {
         final String[] Norfolk = new String[] {
                "N\u1ecd\u0301rf\u1ecd\u0301lk A\u00edland F\u00edksd Taim",
                "",
-               "N\u1ecd\u0301rf\u1ecd\u0301lk A\u00edland H\u1ecd\u0301t S\u00edzin Taim",
+               "N\u1ecd\u0301rf\u1ecd\u0301lk A\u00edland D\u00e9la\u00edt Taim",
                "",
                "N\u1ecd\u0301rf\u1ecd\u0301lk A\u00edland Taim",
                "",
@@ -734,14 +738,6 @@ public class TimeZoneNames_pcm extends TimeZoneNamesBundle {
                "L\u1ecdd Ha\u00fa Taim",
                "",
             };
-        final String[] Macquarie = new String[] {
-               "Makwu\u00e9\u00ed A\u00edland Taim",
-               "",
-               "",
-               "",
-               "",
-               "",
-            };
         final String[] Marquesas = new String[] {
                "Makw\u1eb9\u0301sas Taim",
                "",
@@ -1268,7 +1264,7 @@ public class TimeZoneNames_pcm extends TimeZoneNamesBundle {
             { "Asia/Macau", China },
             { "Asia/Qatar", Arabian },
             { "Asia/Seoul", Korea },
-            { "Africa/Juba", Africa_Eastern },
+            { "Africa/Juba", Africa_Central },
             { "Africa/Lome", GMT },
             { "Asia/Almaty", Kazakhstan_Eastern },
             { "Asia/Aqtobe", Kazakhstan_Western },
@@ -1416,7 +1412,7 @@ public class TimeZoneNames_pcm extends TimeZoneNamesBundle {
             { "America/Cancun", America_Eastern },
             { "America/Cayman", America_Eastern },
             { "America/Cuiaba", Amazon },
-            { "America/Dawson", America_Pacific },
+            { "America/Dawson", Yukon },
             { "America/Guyana", Guyana },
             { "America/Havana", Cuba },
             { "America/Inuvik", America_Mountain },
@@ -1540,7 +1536,6 @@ public class TimeZoneNames_pcm extends TimeZoneNamesBundle {
             { "America/St_Kitts", Atlantic },
             { "America/St_Lucia", Atlantic },
             { "America/Winnipeg", America_Central },
-            { "Antarctica/Casey", Australia_Western },
             { "Antarctica/Davis", Davis },
             { "Antarctica/Syowa", Syowa },
             { "Antarctica/Troll", GMT },
@@ -1620,7 +1615,7 @@ public class TimeZoneNames_pcm extends TimeZoneNamesBundle {
             { "America/Montserrat", Atlantic },
             { "America/Paramaribo", Suriname },
             { "America/St_Vincent", Atlantic },
-            { "America/Whitehorse", America_Pacific },
+            { "America/Whitehorse", Yukon },
             { "Antarctica/McMurdo", New_Zealand },
             { "Antarctica/Rothera", Rothera },
             { "Asia/Yekaterinburg", Yekaterinburg },
@@ -1660,7 +1655,7 @@ public class TimeZoneNames_pcm extends TimeZoneNamesBundle {
             { "America/Rankin_Inlet", America_Central },
             { "America/Santa_Isabel", Mexico_Northwest },
             { "America/Scoresbysund", Greenland_Eastern },
-            { "Antarctica/Macquarie", Macquarie },
+            { "Antarctica/Macquarie", Australia_Eastern },
             { "Pacific/Port_Moresby", Papua_New_Guinea },
             { "America/Cambridge_Bay", America_Mountain },
             { "America/Coral_Harbour", America_Eastern },
